"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.accountDefaultValues = {
    publicKey: undefined,
    balance: '0',
    username: null,
    nonce: '0',
    producedBlocks: 0,
    fees: '0',
    rewards: '0',
    totalVotesReceived: '0',
    votes: [],
    unlocking: [],
    delegate: {
        lastForgedHeight: 0,
        consecutiveMissedBlocks: 0,
        isBanned: false,
        pomHeights: [],
    },
    asset: {},
    keys: {
        mandatoryKeys: [],
        optionalKeys: [],
        numberOfSignatures: 0,
    },
    missedBlocks: 0,
    isDelegate: 0,
};
class Account {
    constructor(accountInfo) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q;
        this.address = accountInfo.address;
        this.balance = accountInfo.balance
            ? BigInt(accountInfo.balance)
            : BigInt(0);
        this.nonce = accountInfo.nonce ? BigInt(accountInfo.nonce) : BigInt(0);
        this.producedBlocks = accountInfo.producedBlocks;
        this.publicKey = accountInfo.publicKey;
        this.username = accountInfo.username;
        this.fees = accountInfo.fees ? BigInt(accountInfo.fees) : BigInt(0);
        this.rewards = accountInfo.rewards
            ? BigInt(accountInfo.rewards)
            : BigInt(0);
        this.asset = accountInfo.asset;
        this.votes = ((_a = accountInfo.votes) === null || _a === void 0 ? void 0 : _a.length) ? accountInfo.votes.map(vote => ({
            delegateAddress: vote.delegateAddress,
            amount: BigInt(vote.amount),
        }))
            : [];
        this.unlocking = ((_b = accountInfo.unlocking) === null || _b === void 0 ? void 0 : _b.length) ? accountInfo.unlocking.map(unlock => ({
            delegateAddress: unlock.delegateAddress,
            amount: BigInt(unlock.amount),
            unvoteHeight: unlock.unvoteHeight,
        }))
            : [];
        this.totalVotesReceived = BigInt((_c = accountInfo.totalVotesReceived) !== null && _c !== void 0 ? _c : 0);
        this.delegate = {
            lastForgedHeight: (_e = (_d = accountInfo.delegate) === null || _d === void 0 ? void 0 : _d.lastForgedHeight) !== null && _e !== void 0 ? _e : 0,
            consecutiveMissedBlocks: (_g = (_f = accountInfo.delegate) === null || _f === void 0 ? void 0 : _f.consecutiveMissedBlocks) !== null && _g !== void 0 ? _g : 0,
            isBanned: (_j = (_h = accountInfo.delegate) === null || _h === void 0 ? void 0 : _h.isBanned) !== null && _j !== void 0 ? _j : false,
            pomHeights: ((_k = accountInfo.delegate) === null || _k === void 0 ? void 0 : _k.pomHeights) ? [...accountInfo.delegate.pomHeights]
                : [],
        };
        this.keys = {
            mandatoryKeys: ((_m = (_l = accountInfo.keys) === null || _l === void 0 ? void 0 : _l.mandatoryKeys) === null || _m === void 0 ? void 0 : _m.length) ? [...accountInfo.keys.mandatoryKeys]
                : [],
            optionalKeys: ((_p = (_o = accountInfo.keys) === null || _o === void 0 ? void 0 : _o.optionalKeys) === null || _p === void 0 ? void 0 : _p.length) ? [...accountInfo.keys.optionalKeys]
                : [],
            numberOfSignatures: ((_q = accountInfo.keys) === null || _q === void 0 ? void 0 : _q.numberOfSignatures) || 0,
        };
        this.missedBlocks = accountInfo.missedBlocks;
        this.isDelegate = accountInfo.isDelegate;
    }
    toJSON() {
        return {
            address: this.address,
            publicKey: this.publicKey,
            username: this.username,
            balance: this.balance.toString(),
            nonce: this.nonce.toString(),
            producedBlocks: this.producedBlocks,
            fees: this.fees.toString(),
            rewards: this.rewards.toString(),
            totalVotesReceived: this.totalVotesReceived.toString(),
            asset: this.asset,
            votes: this.votes.map(v => ({
                delegateAddress: v.delegateAddress,
                amount: v.amount.toString(),
            })),
            unlocking: this.unlocking.map(v => ({
                delegateAddress: v.delegateAddress,
                amount: v.amount.toString(),
                unvoteHeight: v.unvoteHeight,
            })),
            delegate: {
                lastForgedHeight: this.delegate.lastForgedHeight,
                consecutiveMissedBlocks: this.delegate.consecutiveMissedBlocks,
                isBanned: this.delegate.isBanned,
                pomHeights: this.delegate.pomHeights,
            },
            keys: {
                mandatoryKeys: this.keys.mandatoryKeys,
                optionalKeys: this.keys.optionalKeys,
                numberOfSignatures: this.keys.numberOfSignatures,
            },
            isDelegate: this.isDelegate,
            missedBlocks: this.missedBlocks,
        };
    }
}
exports.Account = Account;
Account.getDefaultAccount = (address) => new Account({
    address,
    ...exports.accountDefaultValues,
});
//# sourceMappingURL=account.js.map