import { BaseTransaction, TransactionJSON } from '@liskhq/lisk-transactions';
import { Account } from '../account';
import { BlockHeader, BlockHeaderJSON, BlockInstance, BlockJSON, Storage as DBStorage, TempBlock } from '../types';
interface DAConstructor {
    readonly dbStorage: DBStorage;
    readonly registeredTransactions: {
        readonly [key: number]: typeof BaseTransaction;
    };
    readonly minBlockHeaderCache: number;
    readonly maxBlockHeaderCache: number;
}
export declare class DataAccess {
    private readonly _storage;
    private readonly _blocksCache;
    private readonly _transactionAdapter;
    constructor({ dbStorage, registeredTransactions, minBlockHeaderCache, maxBlockHeaderCache, }: DAConstructor);
    addBlockHeader(blockHeader: BlockHeader): BlockHeader[];
    removeBlockHeader(id: string): Promise<BlockHeader[]>;
    resetBlockHeaderCache(): void;
    getBlockHeaderByID(id: string): Promise<BlockHeader>;
    getBlockHeadersByIDs(arrayOfBlockIds: ReadonlyArray<string>): Promise<BlockHeader[]>;
    getBlockHeaderByHeight(height: number): Promise<BlockHeader | undefined>;
    getBlockHeadersByHeightBetween(fromHeight: number, toHeight: number): Promise<BlockHeader[]>;
    getBlockHeadersWithHeights(heightList: ReadonlyArray<number>): Promise<BlockHeader[]>;
    getLastBlockHeader(): Promise<BlockHeader>;
    getLastCommonBlockHeader(arrayOfBlockIds: ReadonlyArray<string>): Promise<BlockHeader | undefined>;
    getBlocksCount(): Promise<number>;
    getBlockByID(id: string): Promise<BlockInstance | undefined>;
    getBlocksByIDs(arrayOfBlockIds: ReadonlyArray<string>): Promise<BlockInstance[]>;
    getBlockByHeight(height: number): Promise<BlockHeader | undefined>;
    getBlocksByHeightBetween(fromHeight: number, toHeight: number): Promise<BlockInstance[]>;
    getBlocksWithLimitAndOffset(limit: number, offset?: number): Promise<BlockInstance[]>;
    getLastBlock(): Promise<BlockInstance | undefined>;
    deleteBlocksWithHeightGreaterThan(height: number): Promise<void>;
    isBlockPersisted(blockId: string): Promise<boolean>;
    getTempBlocks(): Promise<TempBlock[]>;
    isTempBlockEmpty(): Promise<boolean>;
    clearTempBlocks(): void;
    getChainState(key: string): Promise<string | undefined>;
    getConsensusState(key: string): Promise<string | undefined>;
    getAccountsByPublicKey(arrayOfPublicKeys: ReadonlyArray<string>): Promise<Account[]>;
    getAccountByAddress(address: string): Promise<Account>;
    getAccountsByAddress(arrayOfAddresses: ReadonlyArray<string>): Promise<Account[]>;
    getDelegates(): Promise<Account[]>;
    resetAccountMemTables(): Promise<void>;
    getTransactionsByIDs(arrayOfTransactionIds: ReadonlyArray<string>): Promise<BaseTransaction[]>;
    isTransactionPersisted(transactionId: string): Promise<boolean>;
    serialize(blockInstance: BlockInstance): BlockJSON;
    deserialize(blockJSON: BlockJSON): BlockInstance;
    serializeBlockHeader(blockHeader: BlockHeader): BlockHeaderJSON;
    deserializeBlockHeader(blockHeader: BlockHeaderJSON): BlockHeader;
    deserializeTransaction(transactionJSON: TransactionJSON): BaseTransaction;
}
export {};
