import { TransactionJSON } from '@liskhq/lisk-transactions';
import { AccountJSON, BlockJSON, Storage as DBStorage, TempBlock } from '../types';
export declare class Storage {
    private readonly _storage;
    constructor(storage: DBStorage);
    getBlockHeaderByID(id: string): Promise<BlockJSON>;
    getBlockHeadersByIDs(arrayOfBlockIds: ReadonlyArray<string>): Promise<BlockJSON[]>;
    getBlockHeaderByHeight(height: number): Promise<BlockJSON>;
    getBlockHeadersByHeightBetween(fromHeight: number, toHeight: number): Promise<BlockJSON[]>;
    getBlockHeadersWithHeights(heightList: ReadonlyArray<number>): Promise<BlockJSON[]>;
    getLastBlockHeader(): Promise<BlockJSON>;
    getLastCommonBlockHeader(arrayOfBlockIds: ReadonlyArray<string>): Promise<BlockJSON>;
    getBlocksCount(): Promise<number>;
    getBlockByID(id: string): Promise<BlockJSON>;
    getBlocksByIDs(arrayOfBlockIds: ReadonlyArray<string>): Promise<BlockJSON[]>;
    getBlockByHeight(height: number): Promise<BlockJSON>;
    getBlocksByHeightBetween(fromHeight: number, toHeight: number): Promise<BlockJSON[]>;
    getLastBlock(): Promise<BlockJSON>;
    getTempBlocks(): Promise<TempBlock[]>;
    isTempBlockEmpty(): Promise<boolean>;
    clearTempBlocks(): void;
    deleteBlocksWithHeightGreaterThan(height: number): Promise<void>;
    isBlockPersisted(blockId: string): Promise<boolean>;
    getChainState(key: string): Promise<string | undefined>;
    getConsensusState(key: string): Promise<string | undefined>;
    getAccountsByPublicKey(arrayOfPublicKeys: ReadonlyArray<string>): Promise<AccountJSON[]>;
    getAccountByAddress(address: string): Promise<AccountJSON>;
    getAccountsByAddress(arrayOfAddresses: ReadonlyArray<string>): Promise<AccountJSON[]>;
    getDelegates(): Promise<AccountJSON[]>;
    resetAccountMemTables(): Promise<void>;
    getTransactionsByIDs(arrayOfTransactionIds: ReadonlyArray<string>): Promise<TransactionJSON[]>;
    isTransactionPersisted(transactionId: string): Promise<boolean>;
}
