"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class ChainStateStore {
    constructor(chainStateEntity, additionalInformation) {
        this._name = 'ChainState';
        this._chainState = chainStateEntity;
        this._lastBlockHeader = additionalInformation.lastBlockHeader;
        this._networkIdentifier = additionalInformation.networkIdentifier;
        this._lastBlockReward = additionalInformation.lastBlockReward;
        this._data = {};
        this._originalData = {};
        this._updatedKeys = new Set();
        this._originalUpdatedKeys = new Set();
    }
    async cache() {
        const results = await this._chainState.get();
        for (const { key, value } of results) {
            this._data[key] = value;
        }
    }
    get networkIdentifier() {
        return this._networkIdentifier;
    }
    get lastBlockHeader() {
        return this._lastBlockHeader;
    }
    get lastBlockReward() {
        return this._lastBlockReward;
    }
    createSnapshot() {
        this._originalData = { ...this._data };
        this._originalUpdatedKeys = new Set(this._updatedKeys);
    }
    restoreSnapshot() {
        this._data = { ...this._originalData };
        this._updatedKeys = new Set(this._originalUpdatedKeys);
    }
    async get(key) {
        const value = this._data[key];
        if (value) {
            return value;
        }
        const dbValue = await this._chainState.getKey(key);
        if (dbValue === undefined) {
            return dbValue;
        }
        this._data[key] = dbValue;
        return this._data[key];
    }
    getOrDefault() {
        throw new Error(`getOrDefault cannot be called for ${this._name}`);
    }
    find() {
        throw new Error(`getOrDefault cannot be called for ${this._name}`);
    }
    set(key, value) {
        this._data[key] = value;
        this._updatedKeys.add(key);
    }
    async finalize(tx) {
        if (this._updatedKeys.size === 0) {
            return;
        }
        await Promise.all(Array.from(this._updatedKeys).map(key => this._chainState.setKey(key, this._data[key], tx)));
    }
}
exports.ChainStateStore = ChainStateStore;
//# sourceMappingURL=chain_state_store.js.map