"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const account_store_1 = require("./account_store");
const chain_state_store_1 = require("./chain_state_store");
const consensus_state_store_1 = require("./consensus_state_store");
class StateStore {
    constructor(storage, additionalInformation) {
        this.account = new account_store_1.AccountStore(storage.entities.Account);
        this.consensus = new consensus_state_store_1.ConsensusStateStore(storage.entities.ConsensusState, {
            lastBlockHeaders: additionalInformation.lastBlockHeaders,
        });
        this.chain = new chain_state_store_1.ChainStateStore(storage.entities.ChainState, {
            lastBlockHeader: additionalInformation.lastBlockHeaders[0],
            networkIdentifier: additionalInformation.networkIdentifier,
            lastBlockReward: additionalInformation.lastBlockReward,
        });
    }
    createSnapshot() {
        this.account.createSnapshot();
        this.consensus.createSnapshot();
        this.chain.createSnapshot();
    }
    restoreSnapshot() {
        this.account.restoreSnapshot();
        this.consensus.restoreSnapshot();
        this.chain.restoreSnapshot();
    }
    async finalize(tx) {
        await Promise.all([
            this.account.finalize(tx),
            this.chain.finalize(tx),
            this.consensus.finalize(tx),
        ]);
    }
}
exports.StateStore = StateStore;
//# sourceMappingURL=state_store.js.map