"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lisk_transactions_1 = require("@liskhq/lisk-transactions");
exports.composeTransactionSteps = (...steps) => async (transactions, stateStore) => {
    const successfulResponses = [];
    const failedResponses = [];
    for (let i = 0; i < steps.length; i += 1) {
        const filteredTransactions = failedResponses.length > 0
            ? transactions.filter(transaction => !failedResponses.map(res => res.id).includes(transaction.id))
            : transactions;
        const transactionsResponses = stateStore
            ? await steps[i](filteredTransactions, stateStore)
            : steps[i](filteredTransactions);
        for (const response of transactionsResponses) {
            if (response.status !== lisk_transactions_1.Status.OK) {
                failedResponses.push(response);
            }
            if (i === steps.length - 1 && response.status === lisk_transactions_1.Status.OK) {
                successfulResponses.push(response);
            }
        }
    }
    return [...failedResponses, ...successfulResponses];
};
//# sourceMappingURL=compose_transaction_steps.js.map