/// <reference types="node" />
import { Rounds } from './rounds';
import { BlockHeader, Chain, ForgersList, StateStore, VoteWeights } from './types';
interface DelegatesListConstructor {
    readonly rounds: Rounds;
    readonly activeDelegates: number;
    readonly standbyDelegates: number;
    readonly voteWeightCapRate: number;
    readonly standbyThreshold: bigint;
    readonly chain: Chain;
}
export declare const getForgersList: (stateStore: StateStore) => Promise<ForgersList>;
export declare const getVoteWeights: (stateStore: StateStore) => Promise<VoteWeights>;
export declare const deleteForgersListUntilRound: (round: number, stateStore: StateStore) => Promise<void>;
export declare const deleteForgersListAfterRound: (round: number, stateStore: StateStore) => Promise<void>;
export declare const deleteVoteWeightsUntilRound: (round: number, stateStore: StateStore) => Promise<void>;
export declare const deleteVoteWeightsAfterRound: (round: number, stateStore: StateStore) => Promise<void>;
export declare const shuffleDelegateList: (previousRoundSeed1: Buffer, addresses: readonly string[]) => readonly string[];
export declare const getForgerAddressesForRound: (round: number, stateStore: StateStore) => Promise<readonly string[]>;
export declare const isCurrentlyPunished: (height: number, pomHeights: readonly number[]) => boolean;
export declare class DelegatesList {
    private readonly rounds;
    private readonly chain;
    private readonly activeDelegates;
    private readonly standbyDelegates;
    private readonly voteWeightCapRate;
    private readonly standbyThreshold;
    constructor({ activeDelegates, standbyDelegates, standbyThreshold, voteWeightCapRate, rounds, chain, }: DelegatesListConstructor);
    createVoteWeightsSnapshot(height: number, stateStore: StateStore, roundOffset?: number): Promise<void>;
    updateForgersList(round: number, randomSeed: ReadonlyArray<Buffer>, stateStore: StateStore): Promise<void>;
    getDelegateList(round: number): Promise<ReadonlyArray<string>>;
    verifyBlockForger(block: BlockHeader): Promise<boolean>;
}
export {};
