/// <reference types="node" />
export interface StateStore {
    readonly account: {
        readonly get: (primaryValue: string) => Promise<Account>;
        readonly getUpdated: () => Account[];
        readonly set: (primaryValue: string, account: Account) => void;
    };
    readonly consensus: {
        readonly get: (key: string) => Promise<string | undefined>;
        readonly set: (key: string, value: string) => void;
        readonly lastBlockHeaders: ReadonlyArray<BlockHeader>;
    };
}
export interface BlockHeader {
    readonly id: string;
    readonly height: number;
    readonly generatorPublicKey: string;
    readonly seedReveal: string;
    readonly reward: bigint;
    readonly totalFee: bigint;
    readonly timestamp: number;
}
export interface Block extends BlockHeader {
    readonly transactions: any[];
}
interface Vote {
    readonly delegateAddress: string;
    readonly amount: bigint;
}
export interface Account {
    readonly address: string;
    totalVotesReceived: bigint;
    readonly delegate: {
        readonly isBanned: boolean;
        readonly pomHeights: number[];
    };
    readonly votes: Vote[];
    readonly username?: string;
    balance: bigint;
    producedBlocks: number;
    missedBlocks: number;
    fees: bigint;
    rewards: bigint;
    readonly publicKey: string;
}
export interface DPoSProcessingOptions {
    readonly delegateListRoundOffset: number;
    readonly undo?: boolean;
}
export interface Chain {
    readonly slots: {
        readonly getSlotNumber: (epochTime?: number) => number;
    };
    readonly getTotalEarningAndBurnt: (block: BlockHeader) => {
        readonly totalEarning: bigint;
        readonly totalBurnt: bigint;
    };
    readonly dataAccess: {
        readonly getDelegates: () => Promise<Account[]>;
        readonly getConsensusState: (key: string) => Promise<string | undefined>;
        readonly getBlockHeadersByHeightBetween: (fromHeight: number, toHeight: number) => Promise<BlockHeader[]>;
    };
}
export interface DelegateWeight {
    readonly address: string;
    readonly voteWeight: string;
}
export interface VoteWeight {
    readonly round: number;
    readonly delegates: ReadonlyArray<DelegateWeight>;
}
export interface ForgerList {
    readonly round: number;
    readonly delegates: ReadonlyArray<string>;
    readonly standby: ReadonlyArray<string>;
}
export declare type ForgersList = ForgerList[];
export declare type VoteWeights = VoteWeight[];
declare type Grow<T, A extends T[]> = ((x: T, ...xs: A) => void) extends (...a: infer X) => void ? X : never;
declare type GrowToSize<T, A extends T[], N extends number> = {
    readonly 0: A;
    readonly 1: GrowToSize<T, Grow<T, A>, N>;
}[A['length'] extends N ? 0 : 1];
export declare type FixedLengthArray<T, N extends number> = GrowToSize<T, [], N>;
export declare type RandomSeed = Buffer;
export {};
