/// <reference types="node" />
export declare type Transaction = TransactionObject & TransactionFunctions;
export interface TransactionObject {
    readonly id: string;
    readonly nonce: bigint;
    readonly fee: bigint;
    readonly minFee: bigint;
    receivedAt?: Date;
    readonly senderPublicKey: string;
    readonly asset: {
        [key: string]: string | number | ReadonlyArray<string> | undefined;
    };
    signatures?: ReadonlyArray<string>;
    readonly type: number;
    verifiedOnce?: boolean;
    feePriority?: bigint;
}
export interface TransactionFunctions {
    getBytes(): Buffer;
}
export declare enum Status {
    FAIL = 0,
    OK = 1
}
export declare enum TransactionStatus {
    INVALID = 0,
    UNPROCESSABLE = 1,
    PROCESSABLE = 2
}
export interface TransactionError {
    readonly message: string;
    readonly id: string;
    readonly dataPath: string;
    readonly actual?: string | number;
    readonly expected?: string | number;
}
export interface TransactionResponse {
    readonly errors: ReadonlyArray<TransactionError>;
    readonly id: string;
    readonly status: Status;
}
