"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lisk_validator_1 = require("@liskhq/lisk-validator");
const _15_proof_of_misbehavior_transaction_1 = require("./15_proof_of_misbehavior_transaction");
const utils_1 = require("./utils");
const validateInputs = ({ networkIdentifier, fee, nonce, header1, header2, }) => {
    if (!lisk_validator_1.isValidNonce(nonce)) {
        throw new Error('Nonce must be a valid number in string format.');
    }
    if (!lisk_validator_1.isValidFee(fee)) {
        throw new Error('Fee must be a valid number in string format.');
    }
    lisk_validator_1.validateNetworkIdentifier(networkIdentifier);
    if (!header1) {
        throw new Error('Header 1 is required for poof of misbehavior');
    }
    if (!header2) {
        throw new Error('Header 2 is required for poof of misbehavior');
    }
};
exports.reportMisbehavior = (inputs) => {
    validateInputs(inputs);
    const { passphrase, networkIdentifier, header1, header2 } = inputs;
    const transaction = {
        ...utils_1.createBaseTransaction(inputs),
        type: 15,
        asset: {
            header1,
            header2,
        },
    };
    if (!passphrase) {
        return transaction;
    }
    const transactionWithSenderInfo = {
        ...transaction,
        senderPublicKey: transaction.senderPublicKey,
        asset: {
            ...transaction.asset,
        },
    };
    const pomTransaction = new _15_proof_of_misbehavior_transaction_1.ProofOfMisbehaviorTransaction(transactionWithSenderInfo);
    pomTransaction.sign(networkIdentifier, passphrase);
    const { errors } = pomTransaction.validate();
    if (errors.length > 0) {
        throw new Error(errors.toString());
    }
    return pomTransaction.toJSON();
};
//# sourceMappingURL=report_misbehavior.js.map