"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const lisk_cryptography_1 = require("@liskhq/lisk-cryptography");
const command_1 = require("@oclif/command");
const base_1 = tslib_1.__importDefault(require("../../base"));
const flags_1 = require("../../utils/flags");
const reader_1 = require("../../utils/reader");
const processInput = (passphrase) => {
    const { privateKey, publicKey } = lisk_cryptography_1.getKeys(passphrase);
    const address = lisk_cryptography_1.getAddressFromPublicKey(publicKey);
    return {
        privateKey,
        publicKey,
        address,
    };
};
class ShowCommand extends base_1.default {
    async run() {
        const { flags: { passphrase: passphraseSource }, } = this.parse(ShowCommand);
        const passphrase = passphraseSource !== null && passphraseSource !== void 0 ? passphraseSource : (await reader_1.getPassphraseFromPrompt('passphrase', true));
        this.print(processInput(passphrase));
    }
}
exports.default = ShowCommand;
ShowCommand.description = `
		Shows account information for a given passphrase.
	`;
ShowCommand.examples = ['account:show'];
ShowCommand.flags = {
    ...base_1.default.flags,
    passphrase: command_1.flags.string(flags_1.flags.passphrase),
};
//# sourceMappingURL=show.js.map