"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const lisk_cryptography_1 = require("@liskhq/lisk-cryptography");
const lisk_validator_1 = require("@liskhq/lisk-validator");
const command_1 = require("@oclif/command");
const fs_extra_1 = tslib_1.__importDefault(require("fs-extra"));
const path_1 = tslib_1.__importDefault(require("path"));
const base_1 = tslib_1.__importDefault(require("../base"));
class HashOnionCommand extends base_1.default {
    async run() {
        const { flags: { output, count, distance }, } = this.parse(HashOnionCommand);
        if (distance <= 0 || !lisk_validator_1.isValidInteger(distance)) {
            throw new Error('Invalid distance. Distance has to be positive integer');
        }
        if (count <= 0 || !lisk_validator_1.isValidInteger(count)) {
            throw new Error('Invalid count. Count has to be positive integer');
        }
        if (output) {
            const { dir } = path_1.default.parse(output);
            fs_extra_1.default.ensureDirSync(dir);
        }
        const seed = lisk_cryptography_1.generateHashOnionSeed();
        const hashBuffers = lisk_cryptography_1.hashOnion(seed, count, distance);
        const hashes = hashBuffers.map(buf => buf.toString('hex'));
        const result = { count, distance, hashes };
        if (output) {
            fs_extra_1.default.writeJSONSync(output, result);
        }
        else {
            this.print(result);
        }
    }
}
exports.default = HashOnionCommand;
HashOnionCommand.description = `
  Creates hash onion output to be used by forger.
	`;
HashOnionCommand.examples = ['hash-onion --count=1000000 --distance=2000'];
HashOnionCommand.flags = {
    ...base_1.default.flags,
    output: command_1.flags.string({
        char: 'o',
        description: 'Output file path',
    }),
    count: command_1.flags.integer({
        char: 'c',
        description: 'Total number of hashes to produce',
        default: 1000000,
    }),
    distance: command_1.flags.integer({
        char: 'd',
        description: 'Distance between each hashes',
        default: 1000,
    }),
};
//# sourceMappingURL=hash-onion.js.map