"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const lisk_cryptography_1 = require("@liskhq/lisk-cryptography");
const command_1 = require("@oclif/command");
const base_1 = tslib_1.__importDefault(require("../../base"));
const flags_1 = require("../../utils/flags");
const reader_1 = require("../../utils/reader");
const processInputs = (password, encryptedPassphrase) => {
    const encryptedPassphraseObject = lisk_cryptography_1.parseEncryptedPassphrase(encryptedPassphrase);
    const passphrase = lisk_cryptography_1.decryptPassphraseWithPassword(encryptedPassphraseObject, password);
    return { passphrase };
};
class DecryptCommand extends base_1.default {
    async run() {
        const { args, flags: { password: passwordSource }, } = this.parse(DecryptCommand);
        const { encryptedPassphrase } = args;
        const password = passwordSource !== null && passwordSource !== void 0 ? passwordSource : (await reader_1.getPassphraseFromPrompt('password', true));
        const result = processInputs(password, encryptedPassphrase);
        this.print(result);
    }
}
exports.default = DecryptCommand;
DecryptCommand.args = [
    {
        name: 'encryptedPassphrase',
        description: 'Encrypted passphrase to decrypt.',
        required: true,
    },
];
DecryptCommand.description = `
	Decrypts your secret passphrase using the password which was provided at the time of encryption.
	`;
DecryptCommand.examples = [
    'passphrase:decrypt "iterations=1000000&cipherText=9b1c60&iv=5c8843f52ed3c0f2aa0086b0&salt=2240b7f1aa9c899894e528cf5b600e9c&tag=23c01112134317a63bcf3d41ea74e83b&version=1"',
];
DecryptCommand.flags = {
    ...base_1.default.flags,
    password: command_1.flags.string(flags_1.flags.password),
};
//# sourceMappingURL=decrypt.js.map