"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const lisk_cryptography_1 = require("@liskhq/lisk-cryptography");
const command_1 = require("@oclif/command");
const base_1 = tslib_1.__importDefault(require("../../base"));
const flags_1 = require("../../utils/flags");
const reader_1 = require("../../utils/reader");
const outputPublicKeyOptionDescription = 'Includes the public key in the output. This option is provided for the convenience of node operators.';
const processInputs = (passphrase, password, outputPublicKey) => {
    const encryptedPassphraseObject = lisk_cryptography_1.encryptPassphraseWithPassword(passphrase, password);
    const encryptedPassphrase = lisk_cryptography_1.stringifyEncryptedPassphrase(encryptedPassphraseObject);
    return outputPublicKey
        ? {
            encryptedPassphrase,
            publicKey: lisk_cryptography_1.getKeys(passphrase).publicKey,
        }
        : { encryptedPassphrase };
};
class EncryptCommand extends base_1.default {
    async run() {
        const { flags: { passphrase: passphraseSource, password: passwordSource, outputPublicKey, }, } = this.parse(EncryptCommand);
        const passphrase = passphraseSource !== null && passphraseSource !== void 0 ? passphraseSource : (await reader_1.getPassphraseFromPrompt('passphrase', true));
        const password = passwordSource !== null && passwordSource !== void 0 ? passwordSource : (await reader_1.getPassphraseFromPrompt('password', true));
        const result = processInputs(passphrase, password, outputPublicKey);
        this.print(result);
    }
}
exports.default = EncryptCommand;
EncryptCommand.description = `
		Encrypts your secret passphrase under a password.
	`;
EncryptCommand.examples = ['passphrase:encrypt'];
EncryptCommand.flags = {
    ...base_1.default.flags,
    password: command_1.flags.string(flags_1.flags.password),
    passphrase: command_1.flags.string(flags_1.flags.passphrase),
    outputPublicKey: command_1.flags.boolean({
        description: outputPublicKeyOptionDescription,
    }),
};
//# sourceMappingURL=encrypt.js.map