"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const base_1 = tslib_1.__importDefault(require("../../base"));
const flags_1 = require("../../utils/flags");
const delegate_1 = tslib_1.__importDefault(require("./create/delegate"));
const multisignature_1 = tslib_1.__importDefault(require("./create/multisignature"));
const pom_1 = tslib_1.__importDefault(require("./create/pom"));
const transfer_1 = tslib_1.__importDefault(require("./create/transfer"));
const unlock_1 = tslib_1.__importDefault(require("./create/unlock"));
const vote_1 = tslib_1.__importDefault(require("./create/vote"));
const typeNumberMap = {
    '8': 'transfer',
    '10': 'delegate',
    '12': 'multisignature',
    '13': 'vote',
    '14': 'unlock',
    '15': 'pom',
};
const options = Object.entries(typeNumberMap).reduce((accumulated, [key, value]) => [
    ...accumulated,
    key,
    value,
], []);
const typeClassMap = {
    transfer: transfer_1.default,
    vote: vote_1.default,
    delegate: delegate_1.default,
    multisignature: multisignature_1.default,
    unlock: unlock_1.default,
    pom: pom_1.default,
};
const resolveFlags = (accumulated, [key, value]) => {
    if (key === 'type') {
        return accumulated;
    }
    if (typeof value === 'string') {
        return [...accumulated, `--${key}`, value];
    }
    const boolKey = value === false ? `--no-${key}` : `--${key}`;
    return [...accumulated, boolKey];
};
class CreateCommand extends base_1.default {
    async run() {
        const { argv, flags } = this.parse(CreateCommand);
        const { type } = flags;
        const commandType = Object.keys(typeNumberMap).includes(type)
            ? typeNumberMap[type]
            : type;
        const resolvedFlags = Object.entries(flags).reduce(resolveFlags, []);
        await typeClassMap[commandType].run([...argv, ...resolvedFlags]);
    }
}
exports.default = CreateCommand;
CreateCommand.strict = false;
CreateCommand.description = `
	Creates a transaction object.
	`;
CreateCommand.examples = [
    'transaction:create --type=8 1 100 100 13356260975429434553L',
];
CreateCommand.flags = {
    ...base_1.default.flags,
    type: command_1.flags.string({
        char: 't',
        description: 'type of transaction to create',
        required: true,
        options,
    }),
    passphrase: command_1.flags.string(flags_1.flags.passphrase),
    'no-signature': command_1.flags.boolean(flags_1.flags.noSignature),
    networkIdentifier: command_1.flags.string(flags_1.flags.networkIdentifier),
};
//# sourceMappingURL=create.js.map