"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const base_1 = tslib_1.__importDefault(require("../../base"));
const error_1 = require("../../utils/error");
const flags_1 = require("../../utils/flags");
const network_identifier_1 = require("../../utils/network_identifier");
const reader_1 = require("../../utils/reader");
const transactions_1 = require("../../utils/transactions");
const getTransactionInput = async () => {
    try {
        const lines = await reader_1.readStdIn();
        if (!lines.length) {
            throw new error_1.ValidationError('No transaction was provided.');
        }
        return lines[0];
    }
    catch (e) {
        throw new error_1.ValidationError('No transaction was provided.');
    }
};
class VerifyCommand extends base_1.default {
    async run() {
        const { args, flags: { networkIdentifier: networkIdentifierSource }, } = this.parse(VerifyCommand);
        const { transaction } = args;
        const transactionInput = transaction || (await getTransactionInput());
        const transactionObject = transactions_1.parseTransactionString(transactionInput);
        const networkIdentifier = network_identifier_1.getNetworkIdentifierWithInput(networkIdentifierSource, this.userConfig.api.network);
        const txInstance = transactions_1.instantiateTransaction({
            ...transactionObject,
            networkIdentifier,
        });
        const { errors } = txInstance.validate();
        this.print({
            verified: errors.length === 0,
        });
    }
}
exports.default = VerifyCommand;
VerifyCommand.args = [
    {
        name: 'transaction',
        description: 'Transaction to verify in JSON format.',
    },
];
VerifyCommand.description = `
	Verifies a transaction has a valid signature.
	`;
VerifyCommand.examples = ['transaction:verify \'{"type":0,"amount":"100",...}\''];
VerifyCommand.flags = {
    ...base_1.default.flags,
    networkIdentifier: command_1.flags.string(flags_1.flags.passphrase),
};
//# sourceMappingURL=verify.js.map