/// <reference types="node" />
import { BaseTransaction, StateStore, StateStorePrepare } from './base_transaction';
import { TransactionError } from './errors';
import { TransactionResponse } from './response';
import { TransactionJSON } from './transaction_types';
export declare const multisignatureAssetFormatSchema: {
    type: string;
    required: string[];
    properties: {
        numberOfSignatures: {
            type: string;
            minimum: number;
            maximum: number;
        };
        optionalKeys: {
            type: string;
            uniqueItems: boolean;
            minItems: number;
            maxItems: number;
            items: {
                type: string;
                format: string;
            };
        };
        mandatoryKeys: {
            type: string;
            uniqueItems: boolean;
            minItems: number;
            maxItems: number;
            items: {
                type: string;
                format: string;
            };
        };
    };
};
export interface MultiSignatureAsset {
    mandatoryKeys: Array<Readonly<string>>;
    optionalKeys: Array<Readonly<string>>;
    readonly numberOfSignatures: number;
}
export declare class MultisignatureTransaction extends BaseTransaction {
    readonly asset: MultiSignatureAsset;
    static TYPE: number;
    private readonly MAX_KEYS_COUNT;
    constructor(rawTransaction: unknown);
    protected assetToBytes(): Buffer;
    prepare(store: StateStorePrepare): Promise<void>;
    protected verifyAgainstTransactions(transactions: ReadonlyArray<TransactionJSON>): ReadonlyArray<TransactionError>;
    protected validateAsset(): ReadonlyArray<TransactionError>;
    protected applyAsset(store: StateStore): Promise<ReadonlyArray<TransactionError>>;
    protected undoAsset(store: StateStore): Promise<ReadonlyArray<TransactionError>>;
    verifySignatures(store: StateStore): Promise<TransactionResponse>;
    sign(networkIdentifier: string, senderPassphrase: string, passphrases?: ReadonlyArray<string>, keys?: {
        readonly mandatoryKeys: Array<Readonly<string>>;
        readonly optionalKeys: Array<Readonly<string>>;
        readonly numberOfSignatures: number;
    }): void;
}
