"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lisk_validator_1 = require("@liskhq/lisk-validator");
const _13_vote_transaction_1 = require("./13_vote_transaction");
const utils_1 = require("./utils");
const validateInputs = ({ fee, nonce, networkIdentifier, votes, }) => {
    if (!lisk_validator_1.isValidNonce(nonce)) {
        throw new Error('Nonce must be a valid number in string format.');
    }
    if (!lisk_validator_1.isValidFee(fee)) {
        throw new Error('Fee must be a valid number in string format.');
    }
    lisk_validator_1.validateNetworkIdentifier(networkIdentifier);
    if (!(votes === null || votes === void 0 ? void 0 : votes.length)) {
        throw new Error('Votes must present to create transaction.');
    }
};
exports.castVotes = (inputs) => {
    validateInputs(inputs);
    const { networkIdentifier, passphrase, votes } = inputs;
    const transaction = {
        ...utils_1.createBaseTransaction(inputs),
        type: 13,
        asset: {
            votes,
        },
    };
    if (!passphrase) {
        return transaction;
    }
    const transactionWithSenderInfo = {
        ...transaction,
        senderPublicKey: transaction.senderPublicKey,
        asset: {
            ...transaction.asset,
        },
    };
    const voteTransaction = new _13_vote_transaction_1.VoteTransaction(transactionWithSenderInfo);
    voteTransaction.sign(networkIdentifier, passphrase);
    const { errors } = voteTransaction.validate();
    if (errors.length > 0) {
        throw new Error(errors.toString());
    }
    return voteTransaction.toJSON();
};
//# sourceMappingURL=cast_votes.js.map