"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lisk_validator_1 = require("@liskhq/lisk-validator");
const _14_unlock_transaction_1 = require("./14_unlock_transaction");
const utils_1 = require("./utils");
const validateInputs = ({ fee, nonce, networkIdentifier, unlockingObjects, }) => {
    if (!lisk_validator_1.isValidNonce(nonce)) {
        throw new Error('Nonce must be a valid number in string format.');
    }
    if (!lisk_validator_1.isValidFee(fee)) {
        throw new Error('Fee must be a valid number in string format.');
    }
    lisk_validator_1.validateNetworkIdentifier(networkIdentifier);
    if (!(unlockingObjects === null || unlockingObjects === void 0 ? void 0 : unlockingObjects.length)) {
        throw new Error('Unlocking object must present to create transaction.');
    }
};
exports.unlockToken = (inputs) => {
    validateInputs(inputs);
    const { networkIdentifier, passphrase, unlockingObjects } = inputs;
    const transaction = {
        ...utils_1.createBaseTransaction(inputs),
        type: _14_unlock_transaction_1.UnlockTransaction.TYPE,
        asset: {
            unlockingObjects,
        },
    };
    if (!passphrase) {
        return transaction;
    }
    const transactionWithSenderInfo = {
        ...transaction,
        senderPublicKey: transaction.senderPublicKey,
        asset: {
            ...transaction.asset,
        },
    };
    const unlockTransaction = new _14_unlock_transaction_1.UnlockTransaction(transactionWithSenderInfo);
    unlockTransaction.sign(networkIdentifier, passphrase);
    const { errors } = unlockTransaction.validate();
    if (errors.length > 0) {
        throw new Error(errors.toString());
    }
    return unlockTransaction.toJSON();
};
//# sourceMappingURL=unlock_token.js.map